@@ -1,6 +1,6 @@
 package Mason::Test::Class;
 BEGIN {
-  $Mason::Test::Class::VERSION = '2.03';
+  $Mason::Test::Class::VERSION = '2.04';
 }
 use Carp;
 use File::Basename;
@@ -56,15 +56,16 @@ method setup_interp () {
 method create_interp () {
     my (%params) = @_;
     $params{plugins} = $default_plugins if @$default_plugins;
+    rmtree( $self->data_dir );
     return Mason->new(
-        comp_root              => $self->comp_root,
-        data_dir               => $self->data_dir,
-        no_source_line_numbers => 1,
+        comp_root => $self->comp_root,
+        data_dir  => $self->data_dir,
         %params,
     );
 }
 
 method add_comp (%params) {
+    $self->_validate_keys( \%params, qw(path src v verbose) );
     my $path    = $params{path} || die "must pass path";
     my $source  = $params{src}  || " ";
     my $verbose = $params{v}    || $params{verbose};
@@ -84,19 +85,26 @@ method remove_comp (%params) {
     unlink($source_file);
 }
 
-method test_comp (%params) {
-    my $caller = ( caller(1) )[3];
+method _gen_comp_path () {
+    my $caller = ( caller(2) )[3];
     my ($caller_base) = ( $caller =~ /([^:]+)$/ );
-    my $path    = $params{path} || ( "/$caller_base" . ( ++$gen_path_count ) . ".m" );
+    my $path = "/$caller_base" . ( ++$gen_path_count ) . ".m";
+    return $path;
+}
+
+method test_comp (%params) {
+    my $path    = $params{path} || $self->_gen_comp_path;
     my $source  = $params{src}  || " ";
     my $verbose = $params{v}    || $params{verbose};
 
     $self->add_comp( path => $path, src => $source, verbose => $verbose );
+    delete( $params{src} );
 
     $self->test_existing_comp( %params, path => $path );
 }
 
 method test_existing_comp (%params) {
+    $self->_validate_keys( \%params, qw(args desc expect expect_data expect_error path v verbose) );
     my $path         = $params{path} or die "must pass path";
     my $caller       = ( caller(1) )[3];
     my $desc         = $params{desc} || $path;
@@ -133,6 +141,7 @@ method test_existing_comp (%params) {
 method run_test_in_comp (%params) {
     my $test = delete( $params{test} ) || die "must pass test";
     my $args = delete( $params{args} ) || {};
+    $params{path} ||= $self->_gen_comp_path;
     $self->add_comp( %params, src => '% $.args->{_test}->($self);' );
     ( my $request_path = $params{path} ) =~ s/\.m$//;
     my @run_params = ( $request_path, %$args );
@@ -176,4 +185,11 @@ method mkpath_and_write_file ( $source_file, $source ) {
     write_file( $source_file, $source );
 }
 
+method _validate_keys ( $params, @allowed_keys ) {
+    my %is_allowed = map { ( $_, 1 ) } @allowed_keys;
+    if ( my @bad_keys = grep { !$is_allowed{$_} } keys(%$params) ) {
+        croak "bad parameters: " . join( ", ", @bad_keys );
+    }
+}
+
 1;
