@@ -1,14 +1,19 @@
 package Mason::t::Errors;
 BEGIN {
-  $Mason::t::Errors::VERSION = '2.03';
+  $Mason::t::Errors::VERSION = '2.04';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
-sub test_errors : Test(22) {
+sub test_comp_errors : Test(31) {
     my $self = shift;
     my $try  = sub {
-        my ( $src, $expect_error ) = @_;
-        $self->test_comp( src => $src, expect_error => $expect_error, desc => $expect_error );
+        my ( $src, $expect_error, %extra ) = @_;
+        $self->test_comp(
+            src          => $src,
+            expect_error => $expect_error,
+            desc         => $expect_error,
+            %extra
+        );
     };
     my $root = $self->interp->comp_root->[0];
 
@@ -20,6 +25,8 @@ sub test_errors : Test(22) {
     $try->( '<%before>',                    qr/<%before> block requires a name/ );
     $try->( '<%init>',                      qr/<%init> without matching <\/%init>/ );
     $try->( '<%attr>',                      qr/unknown block '<%attr>'/ );
+    $try->( '<%blah>',                      qr/unknown block '<%blah>'/ );
+    $try->( '<%init foo>',                  qr/<%init> block does not take a name/ );
     $try->( '<%',                           qr/'<%' without matching '%>'/ );
     $try->( '<& foo',                       qr/'<&' without matching '&>'/ );
     $try->( '%my $i = 1;',                  qr/% must be followed by whitespace/ );
@@ -40,9 +47,30 @@ sub test_errors : Test(22) {
         "<%before a>Hi</%before>\n<%before a>Bye</%before>",
         qr/Duplicate definition of method modifier 'before a'/
     );
+    $try->(
+        '<%method b><%after main>Hi</%after></%method>',
+        qr/Cannot nest <%after> block inside <%method> block/
+    );
     $try->( '<% "foobar" { %>Hi</%>',        qr/'foobar' is neither a code ref/ );
     $try->( "<%flags>\nfoo => 1\n</%flags>", qr/Invalid flag 'foo'/ );
-    $try->( '<% $foo %>', qr/Global symbol "\$foo" requires explicit package name/ );
+    $try->( "<%flags>\nextends => 'blah'\n</%flags>",
+        qr/could not load '\/blah' for extends flag/ );
+    $try->( "<%flags>\nextends => %foo\n</%flags>", qr/Global symbol/ );
+    $try->( '<% $foo %>',      qr/Global symbol "\$foo" requires explicit package name/ );
+    $try->( '%% die "bleah";', qr/bleah/ );
+    $try->( 'die "blargh";',   qr/blargh/, path => '/blargh.pm' );
+}
+
+sub test_bad_allow_globals : Test(2) {
+    my $self = shift;
+    throws_ok { $self->create_interp( allow_globals => ['@p'] ) } qr/only scalar globals supported/;
+    throws_ok { $self->create_interp( allow_globals => ['i-'] ) } qr/not a valid/;
+}
+
+sub test_non_comp_errors : Test(1) {
+    my $self = shift;
+    throws_ok( sub { $self->interp->_make_request()->current_comp_class },
+        qr/cannot determine current_comp_class/ );
 }
 
 1;
