@@ -1,6 +1,6 @@
 package Mason::t::Sections;
 BEGIN {
-  $Mason::t::Sections::VERSION = '2.03';
+  $Mason::t::Sections::VERSION = '2.04';
 }
 use Test::Class::Most parent => 'Mason::Test::Class';
 
@@ -134,4 +134,29 @@ EOF
     );
 }
 
+sub test_empty_sections : Test(1) {
+    my $self = shift;
+    $self->test_comp(
+        src => '
+hi
+<%after foo></%after>
+<%around foo></%around>
+<%before foo></%before>
+<%method foo></%method>
+<%filter bar></%filter>
+<%override allow_path_info></%override>
+<%args></%args>
+<%class></%class>
+<%doc></%doc>
+<%flags></%flags>
+<%init></%init>
+<%perl></%perl>
+<%shared></%shared>
+<%text></%text>
+bye
+',
+        expect => "hibye",
+    );
+}
+
 1;
